<?php

namespace Xstartx\Component\Monetka\Administrator\Controller;

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Controller\AdminController;

/**
 * Контроллер для управления настройками.
 */
class SettingsController extends AdminController
{
    /**
     * Отображение представления.
     *
     * @param bool $cachable Кэширование.
     * @param array $urlparams Параметры.
     * @return void
     */
    public function display($cachable = false, $urlparams = [])
    {
        $this->input->set('view', 'settings');
        parent::display($cachable, $urlparams);
    }

    /**
     * Сохранение данных настроек.
     */
    public function save()
    {
        // Проверка токена безопасности
        $this->checkToken();

        // Получение данных из формы
        $data = $this->input->get('jform', [], 'array');

        /** @var \Xstartx\Component\Monetka\Administrator\Model\SettingsModel $model */
        $model = $this->getModel();

        try {
            // Сохраняем данные
            if ($model->saveSettings($data)) {
                Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_SETTINGS_SAVED_SUCCESS'), 'message');
            } else {
                Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_SETTINGS_SAVE_FAILED'), 'error');
            }
        } catch (\Exception $e) {
            Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
        }

        // Перенаправление обратно к настройкам
        $this->setRedirect('index.php?option=com_monetka&view=settings');
    }

    /**
     * Загрузка данных настроек для отображения в форме.
     *
     * @return void
     */
    public function loadSettings()
    {
        /** @var \Xstartx\Component\Monetka\Administrator\Model\SettingsModel $model */
        $model = $this->getModel();

        try {
            // Загружаем данные настроек
            $settings = $model->getSettings();

            if (!$settings) {
                Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_ERROR_LOADING_SETTINGS'), 'error');
            }

            // Устанавливаем данные для формы
            $this->input->set('jform', (array) $settings);
        } catch (\Exception $e) {
            Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
        }

        // Перенаправляем на страницу настроек
        $this->setRedirect('index.php?option=com_monetka&view=settings');
    }

    /**
     * Отмена изменений в форме.
     */
    public function cancel()
    {
        // Проверка токена безопасности
        $this->checkToken();

        // Перенаправление на страницу настроек (без сохранения изменений)
        $this->setRedirect('index.php?option=com_monetka&view=settings');
    }

    /**
     * Создание записи по умолчанию, если таблица пуста.
     *
     * @return void
     */
    public function createDefaultSettings()
    {
        /** @var \Xstartx\Component\Monetka\Administrator\Model\SettingsModel $model */
        $model = $this->getModel();

        try {
            // Создаём запись по умолчанию
            if ($model->createDefaultSettings()) {
                Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_DEFAULT_SETTINGS_CREATED'), 'message');
            } else {
                Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_ERROR_CREATING_DEFAULT_SETTINGS'), 'error');
            }
        } catch (\Exception $e) {
            Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
        }

        // Перенаправляем на страницу настроек
        $this->setRedirect('index.php?option=com_monetka&view=settings');
    }

    public function updateBalance()
    {
        $this->checkToken();
    
        // Получение данных из запроса
        $input = Factory::getApplication()->input;
        $userId = $input->getInt('user_id');
        $groupId = $input->getInt('group_id');
        $newBalance = $input->getFloat('balance');
    
        if (!$userId || !$groupId) {
            echo new \Joomla\CMS\Response\JsonResponse([
                'success' => false,
                'message' => Text::_('COM_MONETKA_ERROR_INVALID_USER_OR_GROUP_ID')
            ]);
            Factory::getApplication()->close();
        }
    
        /** @var \Xstartx\Component\Monetka\Administrator\Model\Monetka_balancesModel $model */
        $model = $this->getModel('Monetka_balances');
    
        try {
            if ($model->updateBalance($userId, $groupId, $newBalance)) {
                echo new \Joomla\CMS\Response\JsonResponse(['success' => true]);
            } else {
                echo new \Joomla\CMS\Response\JsonResponse([
                    'success' => false,
                    'message' => Text::_('COM_MONETKA_ERROR_SAVING_BALANCE')
                ]);
            }
        } catch (\Exception $e) {
            echo new \Joomla\CMS\Response\JsonResponse([
                'success' => false,
                'message' => $e->getMessage()
            ]);
        }
    
        Factory::getApplication()->close();
    }
    
}
 
