<?php

namespace Xstartx\Component\Monetka\Administrator\Extension;

\defined('_JEXEC') or die;

use Joomla\CMS\Categories\CategoryServiceInterface;
use Joomla\CMS\Categories\CategoryServiceTrait;
use Joomla\CMS\Categories\CategoryFactoryInterface;
use Joomla\CMS\Component\Router\RouterServiceInterface;
use Joomla\CMS\Component\Router\RouterServiceTrait;
use Joomla\CMS\Extension\BootableExtensionInterface;
use Joomla\CMS\Extension\MVCComponent;
use Joomla\CMS\HTML\HTMLRegistryAwareTrait;
use Joomla\CMS\Tag\TagServiceInterface;
use Joomla\CMS\Tag\TagServiceTrait;
use Psr\Container\ContainerInterface;
use Joomla\CMS\Log\Log;
use Xstartx\Component\Monetka\Administrator\Service\HTML\AdminMonetkaService;
use Xstartx\Component\Monetka\Administrator\Service\HTML\Monetka;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\CMS\Factory;

/**
 * Класс компонента для com_monetka
 *
 * @since  5.2.0
 */
class MonetkaComponent extends MVCComponent implements
    BootableExtensionInterface,
    CategoryServiceInterface,
    RouterServiceInterface,
    TagServiceInterface
{
    use HTMLRegistryAwareTrait;
    use RouterServiceTrait;
    use CategoryServiceTrait, TagServiceTrait {
        CategoryServiceTrait::getTableNameForSection insteadof TagServiceTrait;
        CategoryServiceTrait::getStateColumnForSection insteadof TagServiceTrait;
    }

    /** @var array Поддерживаемая функциональность */
    protected $supportedFunctionality = [
        'core.state' => true,
    ];

    /** @var ContainerInterface Контейнер */
    private $container;

    /**
     * Инициализация расширения. Это функция для настройки окружения расширения, например,
     * регистрации новых загрузчиков классов и т.д.
     *
     * @param   ContainerInterface  $container  Контейнер
     *
     * @return  void
     *
     * @since   5.2.0
     */
    public function boot(ContainerInterface $container)
    {
        // Регистрация сервиса для административной части
        $this->getRegistry()->register('monetkaadmin', new AdminMonetkaService());
    
        // Регистрация сервиса для фронтенда, но расположенного в административной части
        $this->getRegistry()->register('com_monetka', new Monetka());
    
        // Регистрация 'monetka' как псевдонима для 'monetkafront'
        $this->getRegistry()->register('monetka', $this->getRegistry()->getService('com_monetka'));


        $this->container = $container;
        
        $logFilePath = JPATH_ROOT . '/administrator/logs/com_monetka.log';
        if (!file_exists($logFilePath) || !is_writable(dirname($logFilePath))) {
            Log::add('Файл лога недоступен для записи или не существует: ' . $logFilePath, Log::ERROR, 'monetka');
        }

    }

    /**
     * Устанавливает фабрику категорий через трейт.
     *
     * @param \Joomla\CMS\Categories\CategoryFactoryInterface $categoryFactory Фабрика категорий.
     */
    public function setCategoryFactoryFromTrait(\Joomla\CMS\Categories\CategoryFactoryInterface $categoryFactory): void
    {
        $this->setCategoryFactory($categoryFactory);
    }

    /**
     * Возвращает допустимый раздел для заданного раздела. Если он недействителен, возвращается null.
     *
     * @param   string  $section  Раздел, для которого нужно получить соответствие
     * @param   object  $item     Элемент
     *
     * @return  string|null Новый раздел
     *
     * @since   5.2.0
     */
    public function validateSection($section, $item = null)
    {
        // Пример проверки раздела, адаптируйте под нужды вашего компонента
        if ($section !== 'userbalances') {
            return null;
        }

        return $section;
    }

    /**
     * Возвращает таблицу для функций подсчета элементов для заданного раздела.
     *
     * @param   ?string  $section  Раздел
     *
     * @return  string|null
     *
     * @since   5.2.0
     */
    protected function getTableNameForSection(?string $section = null)
    {
        return '#__monetka_users';
    }
}
 
