<?php

namespace Xstartx\Component\Monetka\Administrator\Model;

use Joomla\CMS\MVC\Model\AdminModel;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;

\defined('_JEXEC') or die;

/**
 * Модель для управления криптовалютами.
 */
class CryptocurrenciesModel extends AdminModel
{
    /**
     * Получение данных для списка криптовалют.
     *
     * @return \Joomla\Database\QueryInterface
     */
    protected function getListQuery()
    {
        // Получаем объект базы данных
        $db = Factory::getContainer()->get('DatabaseDriver');
        $query = $db->getQuery(true);

        // Выбираем данные из таблицы
        $query->select([
            'a.id',
            'a.name',
            'a.symbol',
            'a.price_rub',
            'a.price_usd',
            'a.last_updated',
        ])
        ->from($db->quoteName('#__monetka_cryptocurrencies', 'a'));

        // Проверяем наличие фильтра поиска
        $search = $this->getState('filter.search');
        if (!empty($search)) {
            $query->where('a.name LIKE ' . $db->quote('%' . $search . '%'));
        }

        // Устанавливаем сортировку
        $orderCol = $this->state->get('list.ordering', 'a.id');
        $orderDirn = $this->state->get('list.direction', 'ASC');
        $query->order($db->escape($orderCol . ' ' . $orderDirn));

        return $query;
    }

    /**
     * Получение формы для редактирования данных.
     *
     * @param array $data Данные.
     * @param bool  $loadData Загружать данные.
     *
     * @return \Joomla\CMS\Form\Form|bool Объект формы или false в случае ошибки.
     */
    public function getForm($data = [], $loadData = true)
    {
        $form = $this->loadForm(
            'com_monetka.cryptocurrencies',
            'cryptocurrencies',
            ['control' => 'jform', 'load_data' => $loadData]
        );

        if (!$form) {
            throw new \RuntimeException(Text::_('COM_MONETKA_ERROR_FORM_NOT_FOUND'));
        }

        return $form;
    }

    /**
     * Загрузка данных для формы.
     *
     * @return array Данные формы.
     */
    protected function loadFormData()
    {
        // Получение объекта сессии
        $session = Factory::getContainer()->get('session');
        $data = $session->get('com_monetka.edit.cryptocurrencies.data', []);
    
        return $data ?: $this->getItem();
    }

    /**
     * Сохранение данных криптовалюты.
     *
     * @param array $data Данные для сохранения.
     * @return bool Успех сохранения.
     * @throws \RuntimeException В случае ошибки сохранения.
     */
    public function save($data)
    {
        $table = $this->getTable();

        // Если ID существует, загружаем текущую запись
        if (!empty($data['id']) && !$table->load($data['id'])) {
            throw new \RuntimeException(Text::_('COM_MONETKA_CRYPTOS_NOT_FOUND'));
        }

        // Устанавливаем текущую дату и время изменения
        $data['last_updated'] = Factory::getDate()->toSql();

        // Привязываем данные к таблице
        if (!$table->bind($data)) {
            throw new \RuntimeException(Text::_('COM_MONETKA_CRYPTOS_BIND_FAILED'));
        }

        // Проверяем данные
        if (!$table->check()) {
            throw new \RuntimeException(Text::_('COM_MONETKA_CRYPTOS_CHECK_FAILED'));
        }

        // Сохраняем данные
        if (!$table->store()) {
            throw new \RuntimeException(Text::_('COM_MONETKA_CRYPTOS_SAVE_FAILED'));
        }

        return true;
    }

    /**
     * Получение таблицы для работы с криптовалютами.
     *
     * @param string $type Тип таблицы.
     * @param string $prefix Префикс класса таблицы.
     * @param array  $config Конфигурация таблицы.
     * @return \Joomla\CMS\Table\Table Объект таблицы.
     */
    public function getTable($type = 'Cryptocurrencies', $prefix = 'Xstartx\\Component\\Monetka\\Administrator\\Table', $config = [])
    {
        return parent::getTable($type, $prefix, $config);
    }

    /**
     * Получение одной записи.
     *
     * @param int|null $pk Первичный ключ.
     * @return object Объект записи.
     */
    public function getItem($pk = null)
    {
        return parent::getItem($pk);
    }

    /**
     * Получение списка записей.
     *
     * @return array Список записей.
     */
    public function getItems()
    {
        $db = Factory::getContainer()->get('DatabaseDriver');
        $query = $this->getListQuery();

        try {
            return $db->setQuery($query)->loadObjectList();
        } catch (\RuntimeException $e) {
            throw new \RuntimeException(Text::_('COM_MONETKA_ERROR_FETCHING_ITEMS'), 500, $e);
        }
    }
}
 
