<?php

namespace Xstartx\Component\Monetka\Administrator\Table;

defined('_JEXEC') or die;

use Joomla\CMS\Table\Table;
use Joomla\CMS\Factory;
use Joomla\CMS\Access\Access;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Filter\OutputFilter;
use Joomla\CMS\Versioning\VersionableTableInterface;
use Joomla\CMS\Tag\TaggableTableInterface;
use Joomla\CMS\Tag\TaggableTableTrait;
use Joomla\Database\DatabaseDriver;
use Joomla\Registry\Registry;
use Xstartx\Component\Monetka\Administrator\Helper\MonetkaHelper;

/**
 * Monetka_balance table
 *
 * @since 1.0.0
 */
class Monetka_balanceTable extends Table implements VersionableTableInterface, TaggableTableInterface
{
    use TaggableTableTrait;

    /**
     * Indicates that columns fully support the NULL value in the database
     *
     * @var    boolean
     * @since  4.0.0
     */
    protected $_supportNullValue = true;

    /**
     * Constructor
     *
     * @param   DatabaseDriver  $db  A database connector object
     */
    public function __construct(DatabaseDriver $db)
    {
        $this->typeAlias = 'com_monetka.monetka_balance';
        parent::__construct('#__monetka_users', 'id', $db);
        $this->setColumnAlias('published', 'state');
    }

    /**
     * Get the type alias for the history table
     *
     * @return  string  The alias as described above
     *
     * @since   1.0.0
     */
    public function getTypeAlias()
    {
        return $this->typeAlias;
    }

    /**
     * Define a namespaced asset name for inclusion in the #__assets table
     *
     * @return string The asset name
     */
    protected function _getAssetName()
    {
        $k = $this->_tbl_key;
        return $this->typeAlias . '.' . (int) $this->$k;
    }

    /**
     * Returns the parent asset's id. If you have a tree structure, retrieve the parent's id using the external key field
     *
     * @param   Table   $table  Table name
     * @param   integer $id     Id
     *
     * @return mixed The id on success, false on failure.
     */
    protected function _getAssetParentId($table = null, $id = null)
    {
        // Используем объект базы данных через внедрение зависимостей
        $db = $this->getDbo();
    
        // Формируем запрос для получения ID записи с именем "com_monetka"
        $query = $db->getQuery(true)
            ->select($db->quoteName('id'))
            ->from($db->quoteName('#__assets'))
            ->where($db->quoteName('name') . ' = ' . $db->quote('com_monetka'));
    
        $db->setQuery($query);
    
        $parentId = $db->loadResult();
    
        // Если запись не найдена, возвращаем корневой ID
        if (!$parentId) {
            $query = $db->getQuery(true)
                ->select($db->quoteName('id'))
                ->from($db->quoteName('#__assets'))
                ->where($db->quoteName('parent_id') . ' = 0');
    
            $db->setQuery($query);
            $parentId = $db->loadResult();
        }
    
        return $parentId;
    }

    /**
     * Overloaded check function
     *
     * @return bool
     */
    public function check()
    {
        // Проверка на обязательное наличие ID пользователя
        if (empty($this->user_id)) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_ERROR_USER_ID_REQUIRED'), 'error');
            return false;
        }
    
        // Проверка на корректность баланса
        if (isset($this->balance) && !is_numeric($this->balance)) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_ERROR_INVALID_BALANCE'), 'error');
            return false;
        }
    
        // Если есть колонка ordering и новая запись, устанавливаем следующее значение ordering
        if (property_exists($this, 'ordering') && $this->id == 0) {
            $this->ordering = self::getNextOrder();
        }
    
        return parent::check();
    }

    /**
     * This function converts an array of Access objects into a rules array.
     *
     * @param   array  $jaccessrules  An array of Access objects.
     *
     * @return  array
     */
    private function JAccessRulestoArray($jaccessrules)
    {
        $rules = [];

        foreach ($jaccessrules as $action => $jaccess) {
            $actions = [];

            if ($jaccess) {
                foreach ($jaccess->getData() as $group => $allow) {
                    $actions[$group] = (bool) $allow;
                }
            }

            $rules[$action] = $actions;
        }

        return $rules;
    }

    /**
     * Overloaded bind function to pre-process the params.
     *
     * @param   array  $array   Named array
     * @param   mixed  $ignore  Optional array or list of parameters to ignore
     *
     * @return  boolean  True on success.
     */
    public function bind($array, $ignore = '')
    {
        $user = Factory::getApplication()->getIdentity();

        if (isset($array['params']) && is_array($array['params'])) {
            $registry = new Registry;
            $registry->loadArray($array['params']);
            $array['params'] = (string) $registry;
        }

        if (isset($array['metadata']) && is_array($array['metadata'])) {
            $registry = new Registry;
            $registry->loadArray($array['metadata']);
            $array['metadata'] = (string) $registry;
        }

        // Bind the rules for ACL where supported.
        if (isset($array['rules']) && is_array($array['rules'])) {
            $this->setRules($array['rules']);
        }

        return parent::bind($array, $ignore);
    }

    /**
     * Method to store a row in the database from the Table instance properties.
     *
     * @param   boolean  $updateNulls  True to update fields even if they are null.
     *
     * @return  boolean  True on success.
     */
    public function store($updateNulls = true)
    {
        try {
            return parent::store($updateNulls);
        } catch (\RuntimeException $e) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_ERROR_UNIQUE_CONSTRAINT') . ': ' . $e->getMessage(), 'error');
            return false;
        }
    }

    /**
     * Delete a record by id
     *
     * @param   mixed  $pk  Primary key value to delete. Optional
     *
     * @return bool
     */
    public function delete($pk = null)
    {
        $this->load($pk);
        return parent::delete($pk);
    }

    /**
     * Получает баланс пользователя по его ID и, если плагин активен, по ID группы.
     *
     * @param   int  $userId  ID пользователя
     * @param   int|null  $groupId  ID группы, если плагин Jomsocial активен
     * @return float|null Баланс пользователя или null при ошибке
     */
    public function getBalanceByUserAndGroup($userId, $groupId = null)
    {
        if (empty($userId)) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_ERROR_USER_ID_REQUIRED'), 'error');
            return null;
        }
    
        $fieldsExist = MonetkaHelper::checkFieldsExist();
        $jomsocialEnabled = MonetkaHelper::isJomsocialEnabled();

        try {
            if ($fieldsExist && $jomsocialEnabled && $groupId !== null) {
                return MonetkaHelper::getUserBalance($userId, $groupId);
            } else {
                return MonetkaHelper::getUserBalance($userId);
            }
        } catch (\Exception $e) {
            Factory::getApplication()->enqueueMessage(
                Text::sprintf('COM_MONETKA_ERROR_GETTING_BALANCE', $e->getMessage()), 
                'error'
            );
            return null;
        }
    }

    /**
     * Обновляет баланс пользователя.
     *
     * @param   int     $userId  ID пользователя
     * @param   float   $balance Новый баланс
     * @param   int|null $groupId ID группы, если плагин Jomsocial активен
     * @return bool Возвращает true, если баланс успешно обновлён, иначе false
     */
    public function updateBalance($userId, $balance, $groupId = null)
    {
        $fieldsExist = MonetkaHelper::checkFieldsExist();
        $jomsocialEnabled = MonetkaHelper::isJomsocialEnabled();

        try {
            if ($fieldsExist && $jomsocialEnabled && $groupId !== null) {
                return MonetkaHelper::updateUserBalance($userId, $balance, $groupId);
            } else {
                return MonetkaHelper::updateUserBalance($userId, $balance);
            }
        } catch (\Exception $e) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_ERROR_UPDATING_BALANCE') . ': ' . $e->getMessage(), 'error');
            return false;
        }
    }
}
 
