<?php

namespace Xstartx\Component\Monetka\Administrator\Table;

use Joomla\CMS\Table\Table;
use Joomla\CMS\Factory;
use Joomla\Database\DatabaseDriver;
use Joomla\CMS\Language\Text;

defined('_JEXEC') or die;

/**
 * Класс таблицы для работы с настройками.
 */
class SettingsTable extends Table
{
    /**
     * Конструктор.
     *
     * @param DatabaseDriver $db Объект базы данных.
     */
    public function __construct(DatabaseDriver $db)
    {
        parent::__construct('#__monetka_settings', 'id', $db);
    }

    /**
     * Метод проверки данных перед сохранением.
     *
     * @return bool Успешность проверки.
     */
    public function check(): bool
    {
        // Проверка названия монеты
        if (empty($this->site_coin_name)) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_ERROR_SITE_COIN_NAME_REQUIRED'), 'error');
            return false;
        }
    
        // Проверка количества монет для группы
        $this->coins_per_group = $this->coins_per_group ?? 0;
        if (!is_numeric($this->coins_per_group) || $this->coins_per_group < 0) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_ERROR_COINS_PER_GROUP_INVALID'), 'error');
            return false;
        }
    
        // Проверка комиссии сайта
        $this->site_fee_coins = $this->site_fee_coins ?? 0.0;
        if (!is_numeric($this->site_fee_coins) || $this->site_fee_coins < 0) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_ERROR_SITE_FEE_COINS_INVALID'), 'error');
            return false;
        }
    
        // Проверка полей KuCoin API
        if (!empty($this->kucoin_api_key) && empty($this->kucoin_api_secret)) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_ERROR_KUCOIN_SECRET_REQUIRED'), 'error');
            return false;
        }
    
        if (!empty($this->kucoin_api_secret) && empty($this->kucoin_api_key)) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_MONETKA_ERROR_KUCOIN_KEY_REQUIRED'), 'error');
            return false;
        }
    
        return parent::check();
    }
    

    /**
     * Метод загрузки данных.
     *
     * @param mixed $keys   Первичный ключ или массив первичных ключей.
     * @param bool  $reset  Сбрасывать данные перед загрузкой.
     * @return bool Успешность загрузки.
     */
    public function load($keys = null, $reset = true): bool
    {
        return parent::load($keys, $reset);
    }
}
 