<?php
defined('_JEXEC') or die;

use Joomla\CMS\Layout\LayoutHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Session\Session;
use Joomla\CMS\Router\Route;
use Xstartx\Component\Monetka\Administrator\Helper\MonetkaHelper;
use Joomla\CMS\Log\Log;

// Включение тултипов и мультивыбора
HTMLHelper::_('bootstrap.tooltip');
HTMLHelper::_('behavior.multiselect');

// Получаем параметры сортировки
$listOrder = $this->state->get('list.ordering', 'a.id');
$listDirn = $this->state->get('list.direction', 'asc');

// Проверка на наличие полей и активность плагина Jomsocial
$fieldsExist = MonetkaHelper::checkFieldsExist();
$jomsocialEnabled = MonetkaHelper::isJomsocialEnabled();

// Запись в лог статуса плагина
if ($jomsocialEnabled) {
    Factory::getApplication()->enqueueMessage('Плагин Jomsocial активен.', 'info');
    Log::add('Плагин Jomsocial активен.', Log::INFO, 'plg_monetka_jomsocial');
} else {
    Factory::getApplication()->enqueueMessage('Плагин Jomsocial не активен или не установлен.', 'warning');
    Log::add('Плагин Jomsocial не активен.', Log::WARNING, 'plg_monetka_jomsocial');
}

?>

<form action="<?php echo Route::_('index.php?option=com_monetka&view=monetka_balances'); ?>" method="post" id="adminForm" name="adminForm">
    <div class="row">
        <div class="col-md-12">
            <div id="j-main-container" class="j-main-container">
                <?php echo LayoutHelper::render('searchtools.bar', ['view' => $this]); ?>
                <table class="table table-striped">
                    <thead>
                        <tr>
                            <th width="1%" class="nowrap text-center">
                                <!-- Чекбокс для выбора всех элементов -->
                                <?php echo HTMLHelper::_('grid.checkall'); ?>
                            </th>
                            <th class="nowrap">
                                <?php echo Text::_('COM_MONETKA_USER_ID'); ?>
                            </th>
                            <th class="nowrap">
                                <?php echo Text::_('COM_MONETKA_USERNAME'); ?>
                            </th>
                            <?php if ($fieldsExist && $jomsocialEnabled): ?>
                                <th class="nowrap">
                                    <?php echo Text::_('COM_MONETKA_PROJECT'); ?>
                                </th>
                                <th class="nowrap">
                                    <?php echo Text::_('COM_MONETKA_MANAGER'); ?>
                                </th>
                            <?php endif; ?>
                            <th class="nowrap">
                                <?php echo Text::_('COM_MONETKA_BALANCE'); ?>
                            </th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (!empty($this->items)) : ?>
                            <?php foreach ($this->items as $i => $item) : ?>
                                <tr>
                                    <td class="text-center">
                                        <!-- Чекбокс для выбора индивидуального элемента -->
                                        <?php echo HTMLHelper::_('grid.id', $i, $item->id); ?>
                                    </td>
                                    <td>
                                        <?php echo htmlspecialchars($item->user_id, ENT_COMPAT, 'UTF-8'); ?>
                                    </td>
                                    <td>
                                        <?php echo htmlspecialchars($item->username, ENT_COMPAT, 'UTF-8'); ?>
                                    </td>
                                    <?php if ($fieldsExist && $jomsocialEnabled): ?>
                                        <td>
                                            <?php echo htmlspecialchars($item->group_name ?? Text::_('COM_MONETKA_NO_GROUP'), ENT_COMPAT, 'UTF-8'); ?>
                                        </td>
                                        <td>
                                            <?php echo htmlspecialchars($item->manager, ENT_COMPAT, 'UTF-8'); ?>
                                        </td>
                                    <?php endif; ?>
                                    <td>
                                        <input type="text" 
                                            name="balances[<?php echo $item->user_id; ?><?php echo ($fieldsExist && $jomsocialEnabled) ? '][' . $item->group_id : ''; ?>]" 
                                            value="<?php echo htmlspecialchars($item->balance, ENT_COMPAT, 'UTF-8'); ?>" 
                                            class="form-control balance-input" 
                                            data-user-id="<?php echo $item->user_id; ?>" 
                                            <?php if ($fieldsExist && $jomsocialEnabled): ?>
                                                data-group-id="<?php echo $item->group_id; ?>" 
                                            <?php endif; ?>
                                        />
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else : ?>
                            <tr>
                                <td colspan="<?php echo ($fieldsExist && $jomsocialEnabled) ? 6 : 4; ?>"><?php echo Text::_('COM_MONETKA_NO_ITEMS'); ?></td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
                <input type="hidden" name="task" value="" />
                <?php echo HTMLHelper::_('form.token'); ?>
                <?php if ($this->pagination->pagesTotal > 1) : ?>
                    <div class="pagination">
                        <p class="counter">
                            <?php echo $this->pagination->getPagesCounter(); ?>
                        </p>
                        <?php echo $this->pagination->getPaginationLinks(); ?>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
</form>

<script>
    document.addEventListener('DOMContentLoaded', function () {
        // Получаем все элементы ввода баланса
        const inputs = document.querySelectorAll('.balance-input');

        inputs.forEach(input => {
            input.addEventListener('input', function () {
                const userId = this.dataset.userId;
                const groupId = this.dataset.groupId ? this.dataset.groupId : null;
                // Конвертация введенного значения в число с плавающей точкой или 0, если введено не число
                const newBalance = parseFloat(this.value) || 0;

                // Отправка запроса на обновление баланса
                fetch('<?php echo Route::_('index.php?option=com_monetka&task=monetka_balances.updateBalance&format=json'); ?>', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                        'X-CSRF-Token': '<?php echo Session::getFormToken(); ?>'
                    },
                    body: JSON.stringify({
                        user_id: userId,
                        group_id: groupId,
                        balance: newBalance
                    })
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        console.log('<?php echo Text::_('COM_MONETKA_BALANCE_UPDATED_SUCCESS'); ?>');
                    } else {
                        console.error('<?php echo Text::_('COM_MONETKA_BALANCE_UPDATED_ERROR'); ?>');
                    }
                })
                .catch(error => {
                    console.error('Ошибка:', error);
                });
            });
        });
    });
</script>
 
