<?php
defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Installer\InstallerScript;

class Com_MonetkaInstallerScript extends InstallerScript
{
    /**
     * Метод вызывается после удаления компонента.
     * 
     * @param   InstallerAdapter  $parent  Родительский объект установщика
     * @return  boolean
     */
    public function uninstall($parent)
    {
        $this->deletePackage();
        return true;
    }

    /**
     * Удаляет связанный пакет при удалении компонента
     */
    private function deletePackage()
    {
        $db = Factory::getContainer()->get('DatabaseDriver');
        $query = $db->getQuery(true)
            ->delete($db->quoteName('#__extensions'))
            ->where($db->quoteName('type') . ' = ' . $db->quote('package'))
            ->where($db->quoteName('element') . ' = ' . $db->quote('monetka_package'));
        $db->setQuery($query);

        try {
            $db->execute();
            Factory::getApplication()->enqueueMessage('Associated package was successfully deleted.', 'info');
        } catch (Exception $e) {
            Factory::getApplication()->enqueueMessage('Error deleting associated package: ' . $e->getMessage(), 'error');
        }

        // Удаление манифеста пакета
        $manifestPath = realpath(JPATH_ROOT . '/administrator/manifests/packages/monetka_package.xml');
        if (file_exists($manifestPath)) {
            if (@unlink($manifestPath)) {
                Factory::getApplication()->enqueueMessage('Package manifest file deleted.', 'info');
            } else {
                Factory::getApplication()->enqueueMessage('Failed to delete package manifest file.', 'error');
            }
        }
    }

    /**
     * Метод вызывается при обновлении компонента.
     * 
     * @param   InstallerAdapter  $parent  Родительский объект установщика
     * @return  boolean
     */
    public function update($parent)
    {
        $this->addUseKucoinField();
        return true;
    }

    /**
     * Добавляет новое поле use_kucoin в таблицу настроек, если его ещё нет.
     */
    private function addUseKucoinField()
    {
        $db = Factory::getContainer()->get('DatabaseDriver');
        $query = $db->getQuery(true)
            ->select('COUNT(*)')
            ->from('INFORMATION_SCHEMA.COLUMNS')
            ->where('TABLE_NAME = ' . $db->quote($db->getPrefix() . 'monetka_settings'))
            ->where('COLUMN_NAME = ' . $db->quote('use_kucoin'));

        $db->setQuery($query);
        $exists = (bool)$db->loadResult();

        if (!$exists) {
            $alterQuery = 'ALTER TABLE ' . $db->quoteName($db->getPrefix() . 'monetka_settings') . ' ADD ' . $db->quoteName('use_kucoin') . ' TINYINT(1) DEFAULT 0 AFTER ' . $db->quoteName('kucoin_api_passphrase');
            $db->setQuery($alterQuery);
            $db->execute();
            Factory::getApplication()->enqueueMessage('Field use_kucoin was added to the database.', 'info');
        }
    }

    // Здесь можно добавить другие методы для установки и т.д., если они нужны
}
 
