<?php

namespace Xstartx\Component\Monetka\Site\Controller;

use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Factory;
use Joomla\CMS\Log\Log;
use Joomla\CMS\MVC\Controller\BaseController;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\CMS\MVC\View\HtmlView;
use Joomla\Input\Input;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Language\Text;

class UserbalancesController extends BaseController
{
    /**
     * Конструктор контроллера.
     *
     * @param array                     $config   Конфигурация контроллера.
     * @param MVCFactoryInterface|null  $factory  Фабрика MVC.
     * @param CMSApplication|null       $app      Приложение Joomla.
     * @param Input|null                $input    Входные данные.
     */
    public function __construct(array $config = [], ?MVCFactoryInterface $factory = null, ?CMSApplication $app = null, ?Input $input = null)
    {
        $container = Factory::getContainer();

        // Получение зависимостей из контейнера при отсутствии аргументов
        $factory = $factory ?? $container->get(MVCFactoryInterface::class);
        $app = $app ?? $container->get(CMSApplication::class);
        $input = $input ?? $container->get(Input::class);

        parent::__construct($config, $factory, $app, $input);
    }

    /**
     * Метод отображения.
     *
     * @param boolean $cachable Если true, включается кэширование.
     * @param array   $urlparams Параметры URL.
     *
     * @return BaseController
     */
    public function display($cachable = false, $urlparams = []): BaseController
    {
        $document = Factory::getContainer()->get('document');
        $viewType = $document->getType();

        Log::add('Попытка загрузки представления: userbalances', Log::INFO, 'com_monetka');
        Log::add('Тип представления: ' . $viewType, Log::INFO, 'com_monetka');

        try {
            $view = $this->getView('userbalances', $viewType, '', ['base_path' => $this->basePath]);

            if (!$view instanceof HtmlView) {
                throw new \RuntimeException('Не удалось найти представление: userbalances');
            }

            $view->display();

            if (isset($view->redirectToLogin) && $view->redirectToLogin) {
                /** @var SiteApplication $app */
                $app = Factory::getApplication();
                $loginUrl = Route::_('index.php?option=com_users&view=login', false);
                $app->redirect($loginUrl, Text::_('COM_MONETKA_ERROR_USER_NOT_LOGGED_IN'), 'warning');
            }

            Log::add('Представление успешно загружено: ' . get_class($view), Log::INFO, 'com_monetka');
        } catch (\Exception $e) {
            Log::add('Ошибка загрузки представления: ' . $e->getMessage(), Log::ERROR, 'com_monetka');
            throw $e;
        }

        return parent::display($cachable, $urlparams);
    }
}
 
