<?php

namespace Xstartx\Component\Monetka\Site\Dispatcher;

use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Application\SiteApplication;
use Joomla\CMS\Dispatcher\ComponentDispatcher;
use Joomla\Input\Input;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\CMS\HTML\HTMLHelper;

/**
 * Диспетчер для компонента Monetka на сайте (фронтенд)
 *
 * @since  5.2.3
 */
class Dispatcher extends ComponentDispatcher
{
    /**
     * Конструктор для диспетчера.
     *
     * @param   Input   $input   Входные данные
     * @param   CMSApplication  $app  Приложение
     * @param   MVCFactoryInterface  $mvcFactory  Фабрика MVC
     *
     * @since   5.2.3
     */
    public function __construct(?CMSApplication $app = null, ?Input $input = null, ?MVCFactoryInterface $mvcFactory = null)
    {
        parent::__construct($app, $input, $mvcFactory);
    }

    /**
     * Диспетчеризация запроса
     *
     * @return  void
     *
     * @since   5.2.3
     */
    public function dispatch()
    {
        // Убедитесь, что мы работаем с фронтендом
        if (!($this->app instanceof SiteApplication)) {
            throw new \RuntimeException('This dispatcher is only intended for the frontend.');
        }

        // Подключение CSS файла
        $this->loadCSS();

        parent::dispatch();
    }

    /**
     * Метод для загрузки стилей CSS
     *
     * @return  void
     *
     * @since   5.2.3
     */
    protected function loadCSS()
    {
        // Подключаем CSS файл для фронтенда
        HTMLHelper::_('stylesheet', 'com_monetka/list.css', ['version' => 'auto', 'relative' => true]);
    }
}
 
