<?php

namespace Xstartx\Component\Monetka\Site\Helper;

\defined('_JEXEC') or die; // Защита от прямого доступа

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Application\SiteApplication;
use Joomla\Registry\Registry;

/**
 * Вспомогательный класс для компонента Monetka.
 */
class MonetkaHelper
{
    /**
     * Получение информации о компоненте.
     *
     * @return string Информация о компоненте.
     */
    public static function getComponentInfo(): string
    {
        return Text::_('COM_MONETKA_COMPONENT_INFO'); // Использование языковой константы для многоязычности.
    }

    /**
     * Проверка, имеет ли пользователь необходимые права.
     *
     * @param string $action Имя действия (например, 'core.admin', 'core.manage').
     *
     * @return bool Возвращает true, если пользователь имеет права, иначе false.
     */
    public static function canUserPerform(string $action): bool
    {
        $container = Factory::getContainer(); // Получаем контейнер зависимостей.
        $user = $container->get('user'); // Получаем объект текущего пользователя.
        $assetName = 'com_monetka'; // Имя ресурса для проверки.
        return $user->authorise($action, $assetName);
    }

    /**
     * Получение текущего языка.
     *
     * @return string Код текущего языка (например, 'en-GB').
     */
    public static function getCurrentLanguage(): string
    {
        $container = Factory::getContainer(); // Получаем контейнер зависимостей.
        $language = $container->get('language'); // Получаем объект языка.
        return $language->getTag(); // Возвращаем код текущего языка.
    }

    /**
     * Генерация токена для безопасных операций.
     *
     * @return string Сгенерированный токен.
     */
    public static function generateToken(): string
    {
        return bin2hex(random_bytes(16)); // Генерация криптографически безопасного токена.
    }

    /**
     * Получение параметров компонента.
     *
     * @return Registry Параметры компонента.
     */
    public static function getComponentParams(): Registry
    {
        $container = Factory::getContainer(); // Получаем контейнер зависимостей.
        /** @var SiteApplication $app */
        $app = $container->get(SiteApplication::class); // Получаем объект приложения.
        return $app->getParams('com_monetka'); // Возвращаем параметры компонента.
    }

    /**
     * Логирование сообщения в системный лог Joomla.
     *
     * @param string $message Сообщение для логирования.
     * @param string $type    Тип сообщения (например, 'info', 'error').
     */
    public static function logMessage(string $message, string $type = 'info'): void
    {
        $container = Factory::getContainer(); // Получаем контейнер зависимостей.
        /** @var SiteApplication $app */
        $app = $container->get(SiteApplication::class); // Получаем объект приложения.
        $app->enqueueMessage(Text::_($message), $type); // Добавляем сообщение в очередь.
    }
}

