<?php

/**
 * @package     Joomla.Site
 * @subpackage  com_monetka
 *
 * @copyright   (C) 2023 Your Company Name <yourwebsite.com>
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace Xstartx\Component\Monetka\Site\Helper;

use Joomla\CMS\Categories\CategoryNode;
use Joomla\CMS\Language\Multilanguage;

// phpcs:disable PSR1.Files.SideEffects
\defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

/**
 * Помощник для маршрутизации компонента Monetka.
 *
 * @since  1.0.0
 */
abstract class RouteHelper
{
    /**
     * Получить маршрут для балансов пользователя.
     *
     * @param   integer  $id        Идентификатор элемента баланса.
     * @param   integer  $catid     Идентификатор категории. Не используется в данном контексте.
     * @param   string   $language  Код языка.
     * @param   string   $layout    Значение макета.
     *
     * @return  string  Маршрут для балансов пользователя.
     *
     * @since   1.0.0
     */
    public static function getUserBalancesRoute($id = null, $catid = 0, $language = null, $layout = null)
    {
        // Создать ссылку
        $link = 'index.php?option=com_monetka&view=userbalances';

        // ID здесь не используется, так как у нас одно представление для всех балансов
        // Однако, если нужно будет идентифицировать конкретный баланс, можно будет добавить его здесь

        if (!empty($language) && $language !== '*' && Multilanguage::isEnabled()) {
            $link .= '&lang=' . $language;
        }

        if ($layout) {
            $link .= '&layout=' . $layout;
        }

        return $link;
    }

    /**
     * Получить маршрут для категории.
     *
     * @param   integer  $catid     Идентификатор категории.
     * @param   integer  $language  Код языка.
     * @param   string   $layout    Значение макета.
     *
     * @return  string  Маршрут категории.
     *
     * @since   1.0.0
     */
    public static function getCategoryRoute($catid, $language = 0, $layout = null)
    {
        if ($catid instanceof CategoryNode) {
            $id = $catid->id;
        } else {
            $id = (int) $catid;
        }

        if ($id < 1) {
            return '';
        }

        $link = 'index.php?option=com_monetka&view=category&id=' . $id;

        if ($language && $language !== '*' && Multilanguage::isEnabled()) {
            $link .= '&lang=' . $language;
        }

        if ($layout) {
            $link .= '&layout=' . $layout;
        }

        return $link;
    }

    /**
     * Получить маршрут для формы.
     *
     * @param   integer  $id  Идентификатор формы.
     *
     * @return  string  Маршрут формы.
     *
     * @since   1.0.0
     */
    public static function getFormRoute($id)
    {
        return 'index.php?option=com_monetka&task=balance.edit&a_id=' . (int) $id;
    }
}
 
