<?php

namespace Xstartx\Component\Monetka\Site\Model;

use Joomla\CMS\Factory;
use Joomla\CMS\MVC\Model\ListModel;
use Joomla\CMS\Log\Log;
use Joomla\Database\DatabaseDriver;
use RuntimeException;

\defined('_JEXEC') or die;

/**
 * Модель для получения данных балансов пользователя.
 */
class UserbalancesModel extends ListModel
{
    /**
     * Получить баланс пользователей.
     *
     * @return array Данные о балансе.
     */
    public function getUserbalances(): array
    {
        Log::add('UserbalancesModel: getUserbalances() вызван', Log::INFO, 'monetka');
    
        $user = Factory::getApplication()->getIdentity();
        if ($user->guest) {
            throw new RuntimeException('Пользователь не авторизован', 403);
        }
    
        $db = $this->getDatabaseDriver();
        $query = $db->getQuery(true)
            ->select(['username', 'balance'])
            ->from($db->quoteName('#__monetka_users'))
            ->where($db->quoteName('user_id') . ' = ' . (int) $user->id);
    
        try {
            $db->setQuery($query);
            $balances = $db->loadAssocList();
            Log::add('Данные балансов: ' . print_r($balances, true), Log::INFO, 'monetka');
            return $balances ?: [];
        } catch (\Exception $e) {
            throw new RuntimeException('Ошибка выполнения запроса: ' . $e->getMessage(), 500, $e);
        }
    }

    /**
     * Получить драйвер базы данных.
     *
     * @return DatabaseDriver Драйвер базы данных.
     */
    protected function getDatabaseDriver(): DatabaseDriver
    {
        return Factory::getContainer()->get(DatabaseDriver::class);
    }
}
 
