<?php

namespace Xstartx\Component\Monetka\Site\Service;

use Joomla\CMS\Application\SiteApplication;
use Joomla\CMS\Component\Router\RouterView;
use Joomla\CMS\Component\Router\RouterViewConfiguration;
use Joomla\CMS\Component\Router\Rules\MenuRules;
use Joomla\CMS\Component\Router\Rules\StandardRules;
use Joomla\CMS\Component\Router\Rules\NomenuRules;
use Joomla\CMS\Menu\AbstractMenu;

// phpcs:disable PSR1.Files.SideEffects
\defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

/**
 * Routing class of com_monetka
 *
 * @since  1.0.0
 */
class Router extends RouterView
{
    /**
     * Monetka Component router constructor
     *
     * @param   SiteApplication  $app  The application object
     * @param   AbstractMenu     $menu The menu object to work with
     */
    public function __construct(SiteApplication $app, AbstractMenu $menu)
    {
        $userbalances = new RouterViewConfiguration('userbalances');
        $this->registerView($userbalances);

        parent::__construct($app, $menu);

        $this->attachRule(new MenuRules($this));
        $this->attachRule(new StandardRules($this));
        $this->attachRule(new NomenuRules($this));
    }

    /**
     * Method to get the segment(s) for a user balance
     *
     * @param   string  $id     ID of the user balance to retrieve the segments for
     * @param   array   $query  The request that is built right now
     *
     * @return  array|string  The segments of this item
     */
    public function getUserbalancesSegment($id, $query)
    {
        // В данном примере мы не используем ID, так как представление одно
        return ['userbalances'];
    }

    /**
     * Method to get the id for a user balance
     *
     * @param   string  $segment  Segment to retrieve the ID for
     * @param   array   $query    The request that is parsed right now
     *
     * @return  mixed   The id of this item or false
     */
    public function getUserbalancesId($segment, $query)
    {
        // Поскольку у нас одно представление, мы не возвращаем ID
        return null;
    }
}
 
