<?php

namespace Xstartx\Component\Monetka\Site\View\UserBalances;

use Joomla\CMS\Factory;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\Log\Log;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri; // Импортируем класс Uri
use Joomla\CMS\Application\SiteApplication;
use RuntimeException;

\defined('_JEXEC') or die;

/**
 * Представление для отображения балансов пользователя.
 */
class HtmlView extends BaseHtmlView
{
    protected $balances = [];

    public function display($tpl = null)
    {
        Log::add('HtmlView: display() вызван', Log::INFO, 'monetka');
    
        /** @var SiteApplication $app */
        $app = Factory::getApplication();
        $this->user = $app->getIdentity();
    
        // Проверяем, авторизован ли пользователь
        if ($this->user->guest) {
            Log::add('Пользователь не авторизован. Перенаправление на страницу входа.', Log::INFO, 'monetka');
            
            // Получаем текущий URL и формируем URL для входа
            $currentUri = Uri::getInstance()->toString();
            $loginUrl = Route::_('index.php?option=com_users&view=login', false);

            $app->redirect($loginUrl);

            return;
        }
    
        Log::add('Попытка получить балансы для пользователя: ' . $this->user->id, Log::INFO, 'monetka');
    
        /** @var \Xstartx\Component\Monetka\Site\Model\UserbalancesModel|null $model */
        $model = $this->getModel('Userbalances', 'Xstartx\Component\Monetka\Site\Model');
        if ($model === null) {
            throw new RuntimeException(Text::_('COM_MONETKA_ERROR_MODEL_NOT_FOUND'), 500);
        }
    
        if (!method_exists($model, 'getUserbalances')) {
            throw new RuntimeException(Text::_('COM_MONETKA_ERROR_METHOD_NOT_FOUND'), 500);
        }
    
        try {
            $this->balances = $model->getUserbalances();
            if (!is_array($this->balances)) {
                throw new RuntimeException(Text::_('COM_MONETKA_ERROR_INVALID_BALANCES_FORMAT'), 500);
            }
            Log::add('Баланс успешно получен: ' . print_r($this->balances, true), Log::INFO, 'monetka');
        } catch (\Exception $e) {
            throw new RuntimeException(Text::_('COM_MONETKA_ERROR_FETCHING_BALANCES'), 500, $e);
        }
    
        Log::add('Попытка загрузки шаблона: components/com_monetka/site/tmpl/userbalances/default.php', Log::INFO, 'monetka');
    
        parent::display($tpl);
    
        Log::add('Шаблон успешно загружен или попытка загрузки завершена.', Log::INFO, 'monetka');
    }
}
 
